pub struct Page<R: Read + Seek> { /* private fields */ }Implementations
Sourceimpl<R: Read + Seek> Page<R>
impl<R: Read + Seek> Page<R>
pub fn virtual_page(&self) -> &Option<VirtualPage>
pub fn page_model(&self) -> &PageModel
pub fn template(&mut self) -> Result<Option<&TemplateDescriptor>>
pub fn shape_groups(&mut self) -> Result<&HashMap<ShapeGroupUuid, ShapeGroup>>
pub fn points_files(&mut self) -> Result<&HashMap<PointsUuid, Vec<PointsFile>>>
Sourcepub fn is_empty(&mut self) -> Result<bool>
pub fn is_empty(&mut self) -> Result<bool>
Returns true when the page has no renderable strokes — either no shape
groups exist for it, or every shape group is empty. Lazily loads shape
group metadata if it has not been read yet.
pub fn render(&mut self) -> Result<DrawTarget>